#
# mountnfs.sh	Now that TCP/IP is configured, mount the NFS file
#		systems in /etc/fstab if needed. If possible,
#		start the portmapper before mounting (this is needed for
#		Linux 2.1.x and up).
#
#		Also mounts SMB filesystems now, so the name of
#		this script is getting increasingly inaccurate.
#
# Version:	@(#)mountnfs.sh  2.85-16  03-Jun-2004  miquels@cistron.nl
#

VERBOSE=yes
TMPTIME=0
[ -f /etc/default/rcS ] && . /etc/default/rcS
. /etc/init.d/bootclean.sh
. /lib/lsb/init-functions

#
#	Run in a subshell because of I/O redirection.
#
test -f /etc/fstab && (

#
#	Read through fstab line by line. If it is NFS, set the flag
#	for mounting NFS file systems. If any NFS partition is found and it
#	not mounted with the nolock option, we start the portmapper.
#
portmap=no
mount_nfs=no
mount_nfs4=no
mount_smb=no
mount_cifs=no
mount_coda=no
mount_ncp=no
while read device mountpt fstype options
do
	case "$device" in
		""|\#*)
			continue
			;;
	esac

	case "$options" in
		*noauto*)
			continue
			;;
	esac

	if [ "$fstype" = nfs ] || [ "$fstype" = nfs4 ]
	then
		case "$options" in
			*nolock*)
				;;
			*)
				portmap=yes
				;;
		esac
	fi
	if [ "$fstype" = nfs ]
	then
		mount_nfs=yes
	fi
	if [ "$fstype" = nfs4 ]
	then
		mount_nfs4=yes
	fi
	if [ "$fstype" = smbfs ]
	then
		mount_smb=yes
	fi
	if [ "$fstype" = cifs ]
	then
		mount_cifs=yes
	fi
	if [ "$fstype" = coda ]
	then
		mount_coda=yes
	fi
	if [ "$fstype" = ncpfs ]
	then
		mount_ncp=yes
	fi
done

exec 0>&1

if [ "$portmap" = yes ]
then
	if [ -x /sbin/portmap ]
	then
		log_begin_msg "Starting portmapper..."
		start-stop-daemon --start --quiet --oknodo --exec /sbin/portmap
		log_end_msg $?
		sleep 2
	fi
fi

if [ "$mount_nfs" = yes ] || [ "$mount_nfs4" = yes ] ||
   [ "$mount_smb" = yes ] || [ "$mount_cifs" = yes ] ||
   [ "$mount_ncp" = yes ] || [ "$mount_coda" = yes ]
then
	if [ "$mount_nfs" = yes ]; then
		log_begin_msg "Mounting NFS filesystems..."
		mount -a -t nfs
		log_end_msg $?
	fi
	if [ "$mount_nfs4" = yes ]; then
		log_begin_msg "Mounting NFS4 filesystems..."
		mount -a -t nfs4
		log_end_msg $?
	fi
	if [ "$mount_smb" = yes ]; then
		log_begin_msg "Mounting SMB filesystems..."
		mount -a -t smbfs
		log_end_msg $?
	fi
	if [ "$mount_cifs" = yes ]; then
		log_begin_msg "Mounting CIFS filesystems..."
		mount -a -t cifs
		log_end_msg $?
	fi
	if [ "$mount_ncp" = yes ]; then
		log_begin_msg "Mounting NCP filesystems..."
		mount -a -t ncpfs
		log_end_msg $?
	fi
	if [ "$mount_coda" = yes ]; then
		log_begin_msg "Mounting Coda filesystems..."
		mount -a -t coda
		log_end_msg $?
	fi
fi

) < /etc/fstab

#
#       Clean /tmp, /var/lock, /var/run
#
bootclean mountnfs

: exit 0

